==> ind1KG_0.1.3.zip: ind1KG/doc/nov09rv.R <==
###################################################
### chunk number 1: lkd1-1
###################################################
library(ind1KG)
library(Rsamtools)


###################################################
### chunk number 2: workaround
###################################################
readPileup <- selectMethod("readPileup", "connection")


###################################################
### chunk number 3: lkd1-2
###################################################
pup17 <- gzfile(system.file("pileups/n240_17.pup.gz", package="ind1KG"))
c17p.i <- readPileup(pup17, variant="indel")
levels(seqnames(c17p.i))
levels(seqnames(c17p.i)) <- "chr17"
c17p.i


###################################################
### chunk number 4: li
###################################################
library(SNPlocs.Hsapiens.dbSNP.20080617)
c6 <- getSNPlocs("chr6")
head(c6, 5)


###################################################
### chunk number 5: getg
###################################################
library(org.Hs.eg.db)
egid <- get("CDRT4", revmap(org.Hs.egSYMBOL))
kgid <- get(egid, org.Hs.egUCSCKG)
library(GenomicFeatures)
txdb <-
  makeTranscriptDbFromUCSC(genome="hg18",
                           tablename="knownGene")
txloc <- transcripts(txdb)
cdrt4txloc <- txloc[elementMetadata(txloc)$tx_name %in% kgid]
subsetByOverlaps(c17p.i, cdrt4txloc)


###################################################
### chunk number 6: lkm
###################################################
cdrt4txid <- as.character(elementMetadata(cdrt4txloc)$tx_id)
cdrt4exloc <- exonsBy(txdb)[cdrt4txid]
subsetByOverlaps(c17p.i, cdrt4exloc)


###################################################
### chunk number 7: lkd
###################################################
library(ind1KG)
library(snpMatrix)
data(yri240_6)
yri240_6$hm
head(yri240_6$supp, 10)


###################################################
### chunk number 8: lklu
###################################################
library(lumiHumanIDMapping)
con <- lumiHumanIDMapping_dbconn()
dbListTables(con)
dbGetQuery(con, "select * from HumanWG6_V1 limit 5")


###################################################
### chunk number 9: ll
###################################################
sessionInfo()

==> ind1KG_0.1.5.zip: ind1KG/doc/nov09rv.R <==
###################################################
### chunk number 1: lkd1-1
###################################################
#line 67 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
library(ind1KG)
library(Rsamtools)


###################################################
### chunk number 2: workaround
###################################################
#line 71 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
readPileup <- selectMethod("readPileup", "connection")


###################################################
### chunk number 3: lkd1-2
###################################################
#line 74 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
pup17 <- gzfile(system.file("pileups/n240_17.pup.gz", package="ind1KG"))
c17p.i <- readPileup(pup17, variant="indel")
levels(seqnames(c17p.i))
levels(seqnames(c17p.i)) <- "chr17"
c17p.i


###################################################
### chunk number 4: li
###################################################
#line 83 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
library(SNPlocs.Hsapiens.dbSNP.20080617)
c6 <- getSNPlocs("chr6")
head(c6, 5)


###################################################
### chunk number 5: getg
###################################################
#line 108 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
library(org.Hs.eg.db)
egid <- get("CDRT4", revmap(org.Hs.egSYMBOL))
kgid <- get(egid, org.Hs.egUCSCKG)
library(GenomicFeatures)
txdb <-
  makeTranscriptDbFromUCSC(genome="hg18",
                           tablename="knownGene")
txloc <- transcripts(txdb)
cdrt4txloc <- txloc[elementMetadata(txloc)$tx_name %in% kgid]
subsetByOverlaps(c17p.i, cdrt4txloc)


###################################################
### chunk number 6: lkm
###################################################
#line 121 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
cdrt4txid <- as.character(elementMetadata(cdrt4txloc)$tx_id)
cdrt4exloc <- exonsBy(txdb)[cdrt4txid]
subsetByOverlaps(c17p.i, cdrt4exloc)


###################################################
### chunk number 7: lkd
###################################################
#line 148 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
library(ind1KG)
library(snpMatrix)
data(yri240_6)
yri240_6$hm
head(yri240_6$supp, 10)


###################################################
### chunk number 8: lklu
###################################################
#line 166 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
library(lumiHumanIDMapping)
con <- lumiHumanIDMapping_dbconn()
dbListTables(con)
dbGetQuery(con, "select * from HumanWG6_V1 limit 5")


###################################################
### chunk number 9: ll
###################################################
#line 196 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmp0hzNye/R.INSTALL2c65101a/ind1KG/inst/doc/nov09rv.Rnw"
sessionInfo()
